from anacom import *

#unit step signal
t=symbols('t')
##us=anacom.unitstep(t)

#diracdelta
##dd=anacom.diracdelta(t)


#signum
##sg=anacom.signum(t)


#sawtooth
##saw=anacom.sawtooth(t)

#ramp
##rp=anacom.ramp(t)

#pdf from cdf
##x=symbols('x')
##probdensity=(x-5)
##cumulativedensity=anacom.pdf(probdensity,x)

#fourier transform
##G=anacom.fTrans(us,t)
##G1=anacom.fTrans(dd,t)

#value of fourier transform
##Gval=anacom.fTransVal(G,pi)


#inverse fourier
##f=symbols('f')
##fT=1
##invF=anacom.invfTrans(1,f)
##invFval=anacom.invfTransVal(anacom.invfTrans(anacom.fTrans(us,t),f),t,0)

#Amplitude Modulation
##mt,ct=symbols('mt ct')
##mt=sin(t)
####ka=0.5
##ct=cos(t)
##modulatedWave=anacom.ampmod(mt,ka,ct)
##plot(mt)

#---------------------------------------
#Amplitude Modulation and Demodulation using np
##t=np.linspace(0,100,1000)
##em=5*np.cos(2*np.pi*50*t)
##mod_index=1/10
##ec=10*np.cos(2*np.pi*200*t)
##response_characterstic=50*np.pi*2
##lpf=np.exp(-t*response_characterstic)
##z=anacom.ampmodd(em,mod_index,ec)
##s=anacom.demodd(z,ec,lpf)


#DSBSC Modulation
##t=np.linspace(0,1,1000)
##mt=5*np.cos(2*np.pi*50*t)
##ct=10*np.cos(2*np.pi*1000000*t)
##dsbcmodulated=anacom.dsbscmod(mt,ct)

#SSBSC Modulation
##ssbsc=anacom.ssbscmod(5,5,10,10)

#Frequency Modulation
##freqMod=anacom.fremod(5,10,1,5,1)

#Phase Modulation
##phasewave=anacom.PhaseMod(5,0.3,mt,t)

#PWM
##pulsewidth=anacom.pwm(mt,t)

#PAM
##percent=40.0
##TimePeriod=10.0
##Cycles=30
##dt=0.01
##t=np.arange(0,Cycles*TimePeriod,dt);
##pwm= (t%TimePeriod) < (TimePeriod*percent/100)
##x=np.linspace(-10,10,len(pwm))
##y=(np.cos(x))
##anacom.pamd(pwm,y,t)




class Probability:
    def __init__(val):
        self.prob=val
    def checkforLimit(self):
        if (self.val>=0) and (self.val<=1):
            return True
        return False
    def mutuallyExclusive(p1,p2):
        return Probability(p1.val1+p2.val2)
    def complementryProbability(p1):
        return Probability(1-p1.val)
    def notMutuallyExclusive(p1,p2,p3):
        return Probability(p1.val+p2.val-p3.val)
    def partitionExclusion(l):
        if sum(l)==1:
            return True
        return False
    def condtionalProbability(pAIntersectionB,pA):
        return Probability(pAIntersectionB.val/pA.val)



class anacom:
    def __init__():
        pass

    def unitstep(t):
        x=Heaviside(t)
        plot(x)
        return x

    def diracdelta(t):
        k=DiracDelta(t)
        plot(k)
        return k

    def signum(t):
        x=sign(t)
        plot(x)
        return x

    def sawtooth(t):
        saw=symbols('saw')
        saw=t-floor(t)
        plot(saw)
        return saw

    def ramp(t):
        ram=symbols('ram')
        ram=t*Heaviside(t)
        plot(ram)
        return ram

    def pdf(cdf,x):
        S = diff(cdf,x)
        return S

    def absIntegrablewithoutPeriod(g,t):
        if (integrate(g,(t,-oo,oo))<oo) and (integrate(g,(t,-oo,oo))>-oo):
            return True
        else:
            print("Doesn't satisfy Dirchilit's Conditions")
            return False

    def fTrans(g,t):
        G,f=symbols('G f')
        G=integrate(g*exp(-1*2*pi*f*t*i),(t,-oo,oo))
        return G

    def fTransVal(G,freq):
        f=symbols('f')
        return G.subs(f,freq)

    def invfTrans(G,f):
        pi=3.14159
        g,t=symbols('g t')
        g=integrate(G*exp(2*pi*f*t*i),(f,-oo,oo))
        return g

    def invfTransVal(g,t,time):
        return g.subs(t,time)

    def ampmod(ms,m,c):
        s=(1+m*ms)*c
        plot(s)
        return s

    def ssbscmod(am,fm,ac,fc):
        t=np.linspace(0,1,1000)
        s=((am*ac)/2)*np.cos(2*np.pi*(fc+fm)*t)
        plt.plot(s)
        plt.show()
        return s

    def dsbscmod(ms,c):
        s=ms*c
        plt.plot(s)
        plt.show()
        return s

    def fremod(Ac,Fc,Kf,Fm,Am):
        T,t=symbols('T t')
        x = 2*pi*Fm*t
        m = Am*cos(x)
        Z=integrate(m,(t,0,.5))
        y = 2*pi*Fc*t+(2*pi*Kf)*Z
        S=Ac*cos(y)
        plot(S)
        return S

    def PhaseMod(Ac,Kp,k,t):
        fc=1/2
        s=symbols('s')
        s=Ac*cos(2*pi*fc*t+Kp*k)
        plot(s)

    def pwm(k,t):
        st=symbols('st')
        st=t-floor(t)
        pwm=symbols('pwm')
        x=k-st
        pwm=sign(x)
        plot(pwm)
        return pwm

    def ampmodd(ms,m,c):
        s=(1+m*ms)*c
        plt.plot(s)
        plt.show()
        return s

    def demodd(s,c,r):
        x=s*c
        dmod_sig=np.convolve(x,r)/100
        plt.plot(dmod_sig)
        plt.show()
        return dmod_sig

    def pamd(pwm,y,t):
        y[pwm==0]=0
        plt.plot(t,y)
        plt.grid()
        plt.show()
        return y

    
